@@ -620,10 +620,10 @@ impl HttpApiProblem {
         let json = self.json_bytes();
 
         actix_web::HttpResponse::build(actix_status)
-            .header(
+            .append_header((
                 actix_web::http::header::CONTENT_TYPE,
                 PROBLEM_JSON_MEDIA_TYPE,
-            )
+            ))
             .body(json)
     }
 
@@ -679,7 +679,7 @@ impl HttpApiProblem {
         );
         parts.status = self.status_or_internal_server_error();
 
-        salvo::Response::from_hyper(Response::from_parts(parts, body))
+        Response::from_parts(parts, body).into()
     }
 
     /// Creates a [tide] response.
